.. gcm-filters documentation master file, created by
   sphinx-quickstart on Tue Jan 12 09:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``model_catalogs``
==================

Installation
------------

To install from PyPI:
  >>> pip install model_catalogs

To install from conda-forge:
  >>> conda install -c conda-forge model_catalogs

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   demo.ipynb
   catalog_modes.md
   add_model
   paths
   standard_names
   update_boundaries
   aggregations
   whats_new
   api

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Developer

   package_management
   GitHub repository <https://github.com/NOAA-ORR-ERD/model_catalogs>
